@@ -4,8 +4,8 @@
 ;;
 ;; Author: Peter Prevos <peter@prevos.net>
 ;; URL: https://github.com/pprevos/denote-explore/
-;; Package-Version: 20251011.232
-;; Package-Revision: 0fb33ff9e67a
+;; Package-Version: 20251027.911
+;; Package-Revision: 3adc8b4d342b
 ;; Package-Requires: ((emacs "29.1") (denote "4.0") (dash "2.19.1") (denote-regexp "20250415.2202"))
 ;;
 ;; This file is NOT part of GNU Emacs.
@@ -889,7 +889,7 @@ Files which have keywords listed in
 				links-xref)))
 	 (target (mapcar
 		  (lambda (str)
-		    (when (string-match denote-id-regexp str)
+		    (when (string-match denote-date-identifier-regexp str)
 		      (match-string 0 str)))
 		  links))
 	 ;; Zip this lists as an alist (((source . "a") (target "b")) (...))
@@ -1286,7 +1286,7 @@ Optionally analyse TEXT-ONLY files."
 					       (replace-regexp-in-string "circle" "square" x))
 					     dot-header-all))))
 	 (dot-content '())
-	 (nb-core (when (string-match denote-id-regexp type) (match-string 0 type))))
+	 (nb-core (when (string-match denote-date-identifier-regexp type) (match-string 0 type))))
     ;; Nodes
     (dolist (node nodes)
       (let* ((id (cdr (assoc 'id node)))
